@@ -26,7 +26,7 @@ import lightgbm as lgb
 #import core_helper.helper_plot as hp
 #import src.Prj_Core.core_helper.helper_plot as hp
 from data_science_helper import helper_plot as hp
-
+import data_science_helper.helper_dataframe as hd
 
 #import model.general as g
 #import src.Prj_Core.core_helper.model.general as g
@@ -47,7 +47,7 @@ from data_science_helper.model import lgb_model as l
 #import model.scale_pos_weight__lgb_model as spw_lgb_model
 #import model.custom_bagging__lgb_model as cb_lgb_model
 
-def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=None,y_test=None,params=None,enable_umbral_opt=False,metric='average_precision',num_rounds=10000,early_stop=400,log=0,api="train_api",random_state=42,url=None,print_consola=True):
+def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=None,y_test=None,params=None,enable_cls_opt = False, enable_umbral_opt=False,metric='average_precision',num_rounds=10000,early_stop=400,log=0,api="train_api",random_state=42,url=None,print_consola=True):
     start = time.time()
         
     params.update({"metric":metric})
@@ -58,23 +58,78 @@ def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=
             "metric":metric,"num_rounds":num_rounds,"early_stop":early_stop,"log":log,"random_state":random_state,"api":api ,"strategy":strategy,
             "url":url }     
     
-
-    model ,  y_prob_uno_train, y_prob_uno_test    = l.modelar(**args)
-    '''
-    if (strategy=="neg_bagging_fraction__lgb_model"):
-        model , y_prob_uno   = l.modelar(**args)
-    if (strategy=="scale_pos_weight__lgb_model"):
-        model , y_prob_uno   = l.modelar(**args)
-    if (strategy=="custom_bagging__lgb_model"):
-        model , y_prob_uno   = cb_lgb_model.modelar(X_train,y_train,X_test,y_test,url)
-    '''    
-   
     
-    kpis_train = generar_reporte(model,y_prob_uno_train,X_train,y_train,None,url,print_consola)
+    if (enable_cls_opt):
+    
+        list_cls_ini = ['Z_NOTA_M_T_MENOS_1', 'Z_NOTA_C_T_MENOS_1', 'EXTRA_EDAD_T_MENOS_1']+hd.get_bool_columns(X_train)
+        
+        list_cls = hd.Diff(X_train.columns.tolist(),list_cls_ini) 
+        
+    
+        list_sesgo = []
+        last_best_value = 0
+        
+        for COLUMN in list_cls:
+            
+            if len(list_sesgo)>5:
+                break
+            
+            list_cls_ini.append(COLUMN)
+            
+            X_train_ = X_train.copy()             
+            X_train_ = X_train_[list_cls_ini]
+            
+            X_test_ = X_test.copy()             
+            X_test_ = X_test_[list_cls_ini]
+            
+                    
+            args["X_train"]=X_train_
+            args["X_test"]=X_train_
+            args["url"]=None
+    
+            model ,  y_prob_uno_train, y_prob_uno_test    = l.modelar(**args)
+            
+            kpis_train = generar_reporte(model,y_prob_uno_train,X_train,y_train,None,None,print_consola)
+        
+            kpis_test = generar_reporte(model,y_prob_uno_test,X_test,y_test,None,None,print_consola)
+            
+            
+            f1_train = kpis_train[2]
+            f1_test  = kpis_test[2] 
+                
+            SESGO = f1_train  - f1_test
+            
+            sesgo_var = {"COLUMN":COLUMN,"DIFF":SESGO,"F1_TRAIN":f1_train,"F1_TEST":f1_test }
+            
+            if SESGO > 0.15:
+                list_cls_ini.remove(COLUMN)
+                sesgo_var["SESGO"]=True
+                sesgo_var["IMPROVEMENT"]=False
+            else:
+                sesgo_var["SESGO"]=False
+                if f1_test > last_best_value:
+                    last_best_value = f1_test
+                    sesgo_var["IMPROVEMENT"]=True
+                else:
+                    list_cls_ini.remove(COLUMN)
+                    sesgo_var["IMPROVEMENT"]=False
+            print(sesgo_var)     
+            list_sesgo.append(sesgo_var)
+            
+            
+        g.save_json(list_sesgo,url+"/resumen_cls_sesgo.json")
+        g.save_json(list_cls_ini,url+"/list_cls_sin_sesgo.json")           
+
+                        
+        args["X_train"]=X_train[list_cls_ini]
+        args["X_test"]=X_train[list_cls_ini]
+        args["url"]=url
+   
+    model ,  y_prob_uno_train, y_prob_uno_test    = l.modelar(**args)
+    
 
-    kpis_test = generar_reporte(model,y_prob_uno_test,X_test,y_test,None,url,print_consola)
     umbral_opt=0
-    kpis_opt = (0,0,0,0)
+    kpis_opt = (0,0,0,0,0)
     
     if enable_umbral_opt:
         umbral_opt = g.get_opt_threshold(y_test,y_prob_uno_test)   
